/***********************************************************************************************************************
* DISCLAIMER
* This software is supplied by Renesas Electronics Corporation and is only intended for use with Renesas products.
* No other uses are authorized. This software is owned by Renesas Electronics Corporation and is protected under all
* applicable laws, including copyright laws. 
* THIS SOFTWARE IS PROVIDED "AS IS" AND RENESAS MAKES NO WARRANTIES REGARDING THIS SOFTWARE, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
* NON-INFRINGEMENT.  ALL SUCH WARRANTIES ARE EXPRESSLY DISCLAIMED.TO THE MAXIMUM EXTENT PERMITTED NOT PROHIBITED BY
* LAW, NEITHER RENESAS ELECTRONICS CORPORATION NOR ANY OF ITS AFFILIATED COMPANIES SHALL BE LIABLE FOR ANY DIRECT,
* INDIRECT, SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES FOR ANY REASON RELATED TO THIS SOFTWARE, EVEN IF RENESAS OR
* ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
* Renesas reserves the right, without notice, to make changes to this software and to discontinue the availability 
* of this software. By using this software, you agree to the additional terms and conditions found by accessing the 
* following link:
* http://www.renesas.com/disclaimer
*
* Copyright (C) 2019 Renesas Electronics Corporation. All rights reserved.
***********************************************************************************************************************/

/***********************************************************************************************************************
* File Name    : Config_DTC_ELSR18I.c
* Version      : 1.6.0
* Device(s)    : R5F565NEDxFP
* Description  : This file implements device driver for Config_DTC_ELSR18I.
* Creation Date: 2019-10-03
***********************************************************************************************************************/

/***********************************************************************************************************************
Pragma directive
***********************************************************************************************************************/
/* Start user code for pragma. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
Includes
***********************************************************************************************************************/
#include "r_cg_macrodriver.h"
#include "Config_DTC_ELSR18I.h"
/* Start user code for include. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */
#include "r_cg_userdefine.h"

/***********************************************************************************************************************
Global variables and functions
***********************************************************************************************************************/
volatile uint32_t dtc_vector26 __attribute__ ((section (".dtc_vector26")));
volatile st_dtc_data_t dtc_transferdata_vector26[2];
/* Start user code for global. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

/***********************************************************************************************************************
* Function Name: R_Config_DTC_ELSR18I_Create
* Description  : This function initializes the DTC module
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_DTC_ELSR18I_Create(void)
{
    /* Cancel DTC/DMAC module stop state */
    MSTP(DTC) = 0U;

    /* Disable transfer data read skip to clear the flag */
    DTC.DTCCR.BYTE = _08_DTC_TRANSFER_READSKIP_DISABLE;

    /* Set DTC0 transfer data */
    dtc_transferdata_vector26[0].mra_sar = ((uint32_t)(_00_DTC_SRC_ADDRESS_FIXED | _10_DTC_TRANSFER_SIZE_16BIT | 
                                           _00_DTC_TRANSFER_MODE_NORMAL)<<24U) | (_00000000_DTC0_SRC_ADDRESS & 
                                           0x00FFFFFF);
    dtc_transferdata_vector26[0].mrb_dar = ((uint32_t)(_00_DTC_DST_ADDRESS_FIXED | _00_DTC_INTERRUPT_COMPLETED | 
                                           _00_DTC_CHAIN_TRANSFER_CONTINUOUS | _80_DTC_CHAIN_TRANSFER_ENABLED)<<24U) | 
                                           (_00000000_DTC0_DST_ADDRESS & 0x00FFFFFF);
    dtc_transferdata_vector26[0].cra_crb = (uint32_t)(_0001_DTC0_TRANSFER_COUNT_CRA) << 16U;

    /* Set DTC1 transfer data */
    dtc_transferdata_vector26[1].mra_sar = ((uint32_t)(_00_DTC_SRC_ADDRESS_FIXED | _00_DTC_TRANSFER_SIZE_8BIT | 
                                           _00_DTC_TRANSFER_MODE_NORMAL)<<24U) | (_00000000_DTC1_SRC_ADDRESS & 
                                           0x00FFFFFF);
    dtc_transferdata_vector26[1].mrb_dar = ((uint32_t)(_00_DTC_DST_ADDRESS_FIXED | _00_DTC_INTERRUPT_COMPLETED)<<24U)
                                            | (_00000000_DTC1_DST_ADDRESS & 0x00FFFFFF);
    dtc_transferdata_vector26[1].cra_crb = (uint32_t)(_0001_DTC1_TRANSFER_COUNT_CRA) << 16U;

    /* Set transfer data start address in DTC vector table */
    dtc_vector26 = (uint32_t) dtc_transferdata_vector26;

    /* Set address mode */
    DTC.DTCADMOD.BYTE = _01_DTC_ADDRESS_MODE_SHORT;

    /* Set base address */
    DTC.DTCVBR = (void *)0x0003FC00U;

    /* Enable DTC module start */
    DTC.DTCST.BYTE = _01_DTC_MODULE_START;
    
    R_Config_DTC_ELSR18I_Create_UserInit();
}

/***********************************************************************************************************************
* Function Name: R_Config_DTC_ELSR18I_Start
* Description  : This function enables operation of transfer data DTC
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_DTC_ELSR18I_Start(void)
{
    /* Set enable bit for start source interrupt */
    ICU.DTCER[26].BIT.DTCE = 1U;
}

/***********************************************************************************************************************
* Function Name: R_Config_DTC_ELSR18I_Stop
* Description  : This function disables operation of transfer data DTC
* Arguments    : None
* Return Value : None
***********************************************************************************************************************/

void R_Config_DTC_ELSR18I_Stop(void)
{
    /* Clear enable bit for start source interrupt */
    ICU.DTCER[26].BIT.DTCE = 0U;
}

/* Start user code for adding. Do not edit comment generated here */
/* End user code. Do not edit comment generated here */

